    {
    	forward channel,
    	node channel
    }:

    	description:
    		This is for a "composition" panel.

    		This is literally pretty much anything,
    		given that supplements might
    		literally include anything, more or less.

    		DAC_1 is built from shape_pattern_1

    	Every time a new nutrient is found,
    	it is considered unique unless it is
    	in the shapes database.

    		However, the tree structure from NIH
    		needs to be preserved.

    	{ pattern, structure }:
    		channel: [
    			{
    				"links": []
    			},
    			{
    				"links": []
    			}
    		]